function A = ProjectActDisk(bU,bV,nx,ny,hx,hy,Re,Cd,dt,Y,X,k,E,locTurb1)

%-----------------------------------------------------------------------
% setup 

% first derivatives
Dx = kron(speye(ny),D1z(nx,hx));
Dy = kron(D1p(ny,hy),speye(nx));

% Laplacian
L = kron(speye(ny),D2z(nx,hx)) + kron(D2p(ny,hy),spdiags([0;ones(nx-2,1);0],0,nx,nx));

% Cholesky requires positive definite so use -L
Lp = -L;
perp = symamd(Lp); 
Rp = chol(Lp(perp,perp)); 
Rpt = Rp';


for i1 = 1:size(X,2)

%-----------------------------------------------------------------------
% initial conditions

U = X(1:nx*ny,i1);
V = X(nx*ny+1:2*nx*ny,i1);

%-----------------------------------------------------------------------
% time loop 

for step = 1:1

    % linear drag force (not realistic) 
    u_ib = E*U;
    v_ib = E*V;   
    fx = -u_ib;
    fy = -v_ib;
    
    % predict velocity (forward Euler)
    Ut = U + dt * (1/Re*(L*U) - bU.*(Dx*U) - U.*(Dx*bU) - bV.*(Dy*U) - V.*(Dy*bU) + Cd*E'*fx);
    Vt = V + dt * (1/Re*(L*V) - bU.*(Dx*V) - U.*(Dx*bV) - bV.*(Dy*V) - V.*(Dy*bV) + Cd*E'*fy);
    
    % boundary conditions (Dirichlet inflow, convective outflow)
    Ut = reshape(Ut,nx,ny);
    Vt = reshape(Vt,nx,ny);
    Ut(1,:) = 0;
    Vt(1,:) = 0;
    Ut(end,:) = U(end,:) - dt/hx*(U(end,:)-U(end-1,:));
    Vt(end,:) = V(end,:) - dt/hx*(V(end,:)-V(end-1,:));
    Ut = reshape(Ut,[],1);
    Vt = reshape(Vt,[],1);
   
    % Poisson eqn for pressure
    rhs = (Dx*Ut + Dy*Vt)/dt;        
    P(perp,1) = -Rp\(Rpt\rhs(perp));
    
    % correct velocity
    U = Ut - dt*Dx*P;
    V = Vt - dt*Dy*P;

end;

AX(:,i1) = ([U; V] - X(:,i1)) / dt;

end;

A = Y'*AX;

end